@@ -917,6 +917,8 @@ static int process_id(struct lsof_context *ctx, /* context */
     static int pathil = 0;
     char *rest;
     int txts = 0;
+    int enss_fd = 0;
+    int enls_fd = 0;
 
 #if defined(HASSELINUX)
     cntxlist_t *cntxp;
@@ -1184,6 +1186,7 @@ static int process_id(struct lsof_context *ctx, /* context */
             continue;
         (void)make_proc_path(ctx, dpath, i, &path, &pathl, fp->d_name);
         (void)alloc_lfile(ctx, LSOF_FD_NUMERIC, fd);
+        efs = 0;
         if (getlinksrc(path, pbuf, sizeof(pbuf), &rest) < 1) {
             zeromem((char *)&sb, sizeof(sb));
             lnk = ss = 0;
@@ -1205,6 +1208,7 @@ static int process_id(struct lsof_context *ctx, /* context */
             } else {
                 if (HasNFS) {
                     if (lstatsafely(ctx, path, &lsb)) {
+                        enls_fd = errno;
                         (void)statEx(ctx, pbuf, &lsb, &ls);
                         enls = errno;
                     } else {
@@ -1212,6 +1216,7 @@ static int process_id(struct lsof_context *ctx, /* context */
                         ls = SB_ALL;
                     }
                     if (statsafely(ctx, path, &sb)) {
+                        enss_fd = errno;
                         (void)statEx(ctx, pbuf, &sb, &ss);
                         enss = errno;
                     } else {
@@ -1352,6 +1357,12 @@ static int process_id(struct lsof_context *ctx, /* context */
                     enter_nm(ctx, rest);
                 }
 
+               if ((Selflags & SELNLINK) &&
+                   (enss_fd == ESTALE || enls_fd == ESTALE)) {
+                   Lf->sf |= SELNLINK;
+                   (void)add_nma(ctx, " (STALE)", 8);
+                }
+
                 if (Lf->sf)
                     link_lfile(ctx);
             }
