@@ -221,9 +221,9 @@ static void report_HASDCACHE(struct lsof_context *ctx, /* context */
  * report_HASKERNIDCK() -- report HASKERNIDCK state
  */
 
-static void report_HASKERNIDCK(pfx, verb) char *pfx; /* prefix (NULL if none) */
-char *verb;                                          /* verb (NULL if none) */
-{
+static void report_HASKERNIDCK(char *pfx, /* prefix (NULL if none) */
+                               char *verb /* verb (NULL if none) */
+) {
     (void)fprintf(stderr, "%sernel ID check %s%s%s.\n", pfx ? pfx : "",
                   verb ? verb : "", verb ? " " : "",
 
@@ -240,10 +240,10 @@ char *verb;                                          /* verb (NULL if none) */
  * report_SECURITY() -- report *SECURITY states
  */
 
-static void report_SECURITY(pfx, punct) char *pfx; /* prefix (NULL if none) */
-char *punct;                                       /* short foem punctuation
-                                                    * (NULL if none) */
-{
+static void report_SECURITY(char *pfx,  /* prefix (NULL if none) */
+                            char *punct /* short foem punctuation
+                                         * (NULL if none) */
+) {
     fprintf(stderr, "%s%s can list all files%s", pfx ? pfx : "",
 
 #if defined(HASSECURITY)
@@ -264,11 +264,10 @@ char *punct;                                       /* short foem punctuation
  * report_WARNDEVACCESS() -- report WEARNDEVACCESS state
  */
 
-static void report_WARNDEVACCESS(pfx, verb,
-                                 punct) char *pfx; /* prefix (NULL if none) */
-char *verb;                                        /* verb (NULL if none) */
-char *punct;                                       /* punctuation */
-{
+static void report_WARNDEVACCESS(char *pfx,  /* prefix (NULL if none) */
+                                 char *verb, /* verb (NULL if none) */
+                                 char *punct /* punctuation */
+) {
     (void)fprintf(stderr, "%s/dev warnings %s%s%s%s", pfx ? pfx : "",
                   verb ? verb : "", verb ? " " : "",
 
@@ -865,7 +864,7 @@ void usage(struct lsof_context *ctx, /* context */
     if (version) {
 
         /*
-         * Display version information in reponse to ``-v''.
+         * Display version information in response to ``-v''.
          */
         (void)fprintf(stderr, "%s version information:\n", Pn);
         (void)fprintf(stderr, "    revision: %s\n", LSOF_VERSION);
@@ -903,6 +902,8 @@ void usage(struct lsof_context *ctx, /* context */
             (void)fprintf(stderr, "    compiler: %s\n", cp);
         if ((cp = isnullstr(LSOF_CCV)))
             (void)fprintf(stderr, "    compiler version: %s\n", cp);
+        if ((cp = isnullstr(LSOF_CCFLAGS)))
+            (void)fprintf(stderr, "    compiler flags: %s\n", cp);
         if ((cp = isnullstr(LSOF_LDFLAGS)))
             (void)fprintf(stderr, "    loader flags: %s\n", cp);
         if ((cp = isnullstr(LSOF_SYSINFO)))
